### Name: carex
### Title: Carex section Ovales tree, chromosome data, and nodes
### Aliases: carex
### Keywords: datasets

### ** Examples

  data(carex)
  # tree comes in in phylo format, but we need an ouchtree object
  trees <- lapply(carex$ovales.bayesTrees[1:10], ape2ouch) 
  # for expedience, only tests for changes at up to 2 of the first 4 nodes on 10 trees visited in the MCMC phylogenetic analysis
  trialBayesTrees <- runBatchHansen(trees, carex$ovales.data, carex$ovales.nodes[1:4], maxNodes = 2) 
  summary(trialBayesTrees) # summarizes results using summary.hansenBatch and displays the results using print.hansenSummary
  # same analysis as above, but on a single tree
  trialBayesConsensus <- runBatchHansen(ape2ouch(carex$ovales.tree), carex$ovales.data, carex$ovales.nodes[1:4], maxNodes = 2)
  # compares five different models of character change at node 2
  multiModel(carex$ovales.tree, carex$ovales.data, carex$ovales.nodes[[2]])
  # simulates the evolution of the chromosome number under the model-averaged values
  trialSim <- ouSim(trialBayesConsensus, ape2ouch(carex$ovales.tree)) 
  # plots the character simulation, with all branches black
  plot(trialSim) 
  # plots the character simulation, with branch colors changing at all 8 nodes
  plot(trialSim, colors = paintBranches(carex$ovales.nodes[1:4], trees[[1]])) 
  # plots the character simulation, with branch colors changing only at node 2
  plot(trialSim, colors = paintBranches(list(carex$ovales.nodes[[2]]), trees[[1]])) 



